@@ -4,6 +4,7 @@ package api
 
 import (
 	"context"
+	"expvar"
 	"fmt"
 	"net/http"
 	_ "net/http/pprof" //nolint:gosec // Register pprof handlers
@@ -42,6 +43,7 @@ func injectProfilerHandler(mux *http.ServeMux, profilingEnabled bool) {
 	}
 
 	mux.Handle("/debug/pprof/", handler)
+	mux.Handle("/debug/vars/", expvar.Handler())
 }
 
 // GetServer returns a http.Server instance that can serve k6's REST API.
