@@ -17,7 +17,7 @@ var fieldNameExceptions = map[string]string{
 
 // FieldName Returns the JS name for an exported struct field. The name is snake_cased, with respect for
 // certain common initialisms (URL, ID, HTTP, etc).
-func FieldName(t reflect.Type, f reflect.StructField) string {
+func FieldName(_ reflect.Type, f reflect.StructField) string {
 	// PkgPath is non-empty for unexported fields.
 	if f.PkgPath != "" {
 		return ""
@@ -53,7 +53,7 @@ var methodNameExceptions = map[string]string{
 
 // MethodName Returns the JS name for an exported method. The first letter of the method's name is
 // lowercased, otherwise it is unaltered.
-func MethodName(t reflect.Type, m reflect.Method) string {
+func MethodName(_ reflect.Type, m reflect.Method) string {
 	// A field with a name beginning with an X is a constructor, and just gets the prefix stripped.
 	// Note: They also get some special treatment from Bridge(), see further down.
 	if m.Name[0] == 'X' {
