@@ -1,6 +1,7 @@
 package http
 
 import (
+	"errors"
 	"fmt"
 	"sort"
 	"strings"
@@ -70,8 +71,9 @@ func TestExpectedStatuses(t *testing.T) {
 			}
 
 			require.Error(t, err)
-			exc := err.(*goja.Exception)
-			require.Contains(t, exc.Error(), testCase.err)
+			var exc *goja.Exception
+			errors.As(err, &exc)
+			require.ErrorContains(t, exc, testCase.err)
 		})
 	}
 }
@@ -100,7 +102,7 @@ func TestResponseCallbackInAction(t *testing.T) {
 		metrics.HTTPReqTLSHandshakingName,
 	}
 
-	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName)
+	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName) //nolint: gocritic
 
 	testCases := map[string]struct {
 		code            string
@@ -310,7 +312,7 @@ func TestResponseCallbackBatch(t *testing.T) {
 		metrics.HTTPReqTLSHandshakingName,
 	}
 
-	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName)
+	allHTTPMetrics := append(HTTPMetricsWithoutFailed, metrics.HTTPReqFailedName) //nolint:gocritic
 	// IMPORTANT: the tests here depend on the fact that the url they hit can be ordered in the same
 	// order as the expectedSamples even if they are made concurrently
 	testCases := map[string]struct {
