@@ -45,7 +45,7 @@ func TestConstantVUsRun(t *testing.T) {
 
 	var totalIters uint64
 	result.Range(func(key, value interface{}) bool {
-		vuIters := value.(uint64)
+		vuIters := value.(uint64) //nolint:forcetypeassert
 		assert.Equal(t, uint64(5), vuIters)
 		totalIters += vuIters
 		return true
